### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

### [2.0.0](https://github.com/minrk/wurlitzer/compare/1.0.3...2.0.0)

> 25 October 2019

- use selectors instead of select.poll [`#34`](https://github.com/minrk/wurlitzer/pull/34). Requires `selectors2` package on Python < 3.4.

#### [1.0.3](https://github.com/minrk/wurlitzer/compare/1.0.2...1.0.3)

> 13 June 2019

- Add thread lock  [`#30`](https://github.com/minrk/wurlitzer/pull/30)
- using poll instead of select in forwarder [`#24`](https://github.com/minrk/wurlitzer/pull/24)
- setup.py improvements [`#19`](https://github.com/minrk/wurlitzer/pull/19)
- Link blogpost about redirecting stdout/stderr [`#18`](https://github.com/minrk/wurlitzer/pull/18)
- Prevent wurlitzer from entering multiple times [`#27`](https://github.com/minrk/wurlitzer/pull/28)
- fix threading issues [`1c59bb4`](https://github.com/minrk/wurlitzer/commit/1c59bb435da05fe2e48915aa5c9f485575a7ad1b)

#### [1.0.2](https://github.com/minrk/wurlitzer/compare/1.0.1...1.0.2)

> 20 May 2018

- move fflush to a thread [`#16`](https://github.com/minrk/wurlitzer/pull/16)

#### [1.0.1](https://github.com/minrk/wurlitzer/compare/1.0.0...1.0.1)

> 22 January 2018

- avoid unnecessary close of original FDs [`#11`](https://github.com/minrk/wurlitzer/pull/11)

### [1.0.0](https://github.com/minrk/wurlitzer/compare/0.2.0...1.0.0)

> 22 June 2017

- use control pipe to signal closure [`#8`](https://github.com/minrk/wurlitzer/pull/8)

- Do nothing if loaded in terminal IPython [`#2`](https://github.com/minrk/wurlitzer/pull/2)
- retry dup2 on EBUSY [`6e2e906`](https://github.com/minrk/wurlitzer/commit/6e2e906a8f2ffbd5b27d92a147cd59b0d5008041)

#### [0.2.0](https://github.com/minrk/wurlitzer/compare/0.1.2...0.2.0)

> 14 March 2016

- Make it an IPython extension [`5aa2237`](https://github.com/minrk/wurlitzer/commit/5aa22375de5516915bb1cb9168e04430933e86a6)

#### [0.1.2](https://github.com/minrk/wurlitzer/compare/0.1.1...0.1.2)

> 13 March 2016

- flush before entering wurlitzer [`a8b3a85`](https://github.com/minrk/wurlitzer/commit/a8b3a856a576fe50e8771fddad7fcf3b21ae3285)

#### [0.1.1](https://github.com/minrk/wurlitzer/compare/0.1.0...0.1.1)

> 9 March 2016

- fix names in README, long_description [`7f95a69`](https://github.com/minrk/wurlitzer/commit/7f95a690985e9ff2e7360c2c433fa9b9187f8758)

#### 0.1.0

> 9 March 2016

Initial release
